# EnDa Console Application Package (CAPP)
The story behind this python package was that, EnDaTeam, creates too many console applications. We were annoyed about writing same functions again. We are created this package to help us and you, python console applications developers.



## Authors

- [@WBTER](https://www.github.com/WBTER)
- [@EnDaTeam](https://www.github.com/EnDaTeam)


## Features

- Creates custom ERROR outputs
- Gives custom TIPS for users
- Runs custom commands (Clear Terminal)
- Works with a lot of colors
- Show your options to user
- Install needed modules
- Print with slowness
- Creates custom AsciiArt (Banners)
- Prints an outro (to exit)

## Installation

Install the package by github as zip

```bash
pip install CAPP / pip3 install CAPP
```

## Using

After installation, you must to import the module

```bash
  import CAPP
```

